import numpy as np
import matplotlib.pyplot as plt

n_groups = 11

means_men1 = (44, 46, 50, 54, 56, 57, 55, 56, 59, 56, 58)
means_men2 = (46, 46, 54, 55, 58, 60, 57, 58, 57, 58, 61)
means_men3 = (48, 50, 56, 57, 58, 62, 60, 60, 62, 62, 63)
means_men4 = (46, 47, 51, 53, 57, 59, 59, 62, 60, 61, 60)
means_men5 = (50, 52, 57, 57, 59, 61, 59, 63, 61, 62, 62)
means_men6 = (51, 55, 60, 62, 62, 64, 62, 66, 64, 65, 65)

fig, axes = plt.subplots(nrows=2, ncols=3, figsize=(12, 6))  # Increased the height to 10

index = np.arange(n_groups)
bar_width = 0.35
opacity = 0.4
error_config = {'ecolor': '0.3'}

data = [
    (means_men1, 'CodeLlama-7b'),
    (means_men2, 'CodeLlama-13b'),
    (means_men3, 'CodeLlama-34b'),
    (means_men4, 'DeepSeek-Coder-6.7b'),
    (means_men5, 'DeepSeek-Coder-33b'),
    (means_men6, "GPT-3.5-turbo")
]

colors = ['r', 'g', 'b', 'y', 'purple', 'orange']  # Added 'orange' for the sixth group

for i, (men_means, group_title) in enumerate(data):
    row = i // 3
    col = i % 3
    
    rects1 = axes[row, col].bar(index + i * bar_width, men_means, bar_width,
                                 alpha=opacity, color=colors[i % len(colors)],
                                 error_kw=error_config,
                                 label='Python')
    
    for rect in rects1:
        height = rect.get_height()
        axes[row, col].text(rect.get_x() + rect.get_width() / 2, height ,
                            '%d' % int(height), ha='center', va='bottom')
    
    # axes[row, col].set_xlabel('Evolving')
    axes[row, col].set_ylabel('Numbers of successful instances')
    axes[row, col].set_title(group_title)
    axes[row, col].set_xticks(index + bar_width / 2 + i * bar_width)
    axes[row, col].set_xticklabels(('evo0', 'evo1', 'evo2', 'evo3', 'evo4', 'evo5', 'evo6', 'evo7', 'evo8', 'evo9', 'evo10'), rotation=45)
    # axes[row, col].set_ylim([0, max(max(men_means), 0) * 1.1])
    axes[row, col].set_yticks(np.arange(0, max(max(men_means), 0) * 1.35, 10))
# Adjust layout
plt.tight_layout()

# Save as PDF
plt.savefig('RQ2.pdf', format='pdf')

plt.show()
